@@ -3,7 +3,7 @@
 #include <R_ext/Complex.h>
 #include <time.h>
 
-// ceeboo 2012/3+4
+// ceeboo 2012/3+4 2013/10
 //
 
 SEXP _part_index(SEXP x) {
@@ -15,7 +15,8 @@ SEXP _part_index(SEXP x) {
     k = LENGTH(getAttrib(x, R_LevelsSymbol));
 
     r = PROTECT(allocVector(INTSXP, LENGTH(x)));
-    setAttrib(r, install("table"), (t = allocVector(INTSXP, k)));
+    setAttrib(r, install("table"), PROTECT(t = allocVector(INTSXP, k)));
+    UNPROTECT(1);
 
     memset(INTEGER(t), 0, sizeof(int) * k);
 
@@ -390,7 +391,7 @@ SEXP _match_matrix(SEXP x, SEXP y, SEXP _nm) {
 	}
     }
 
-    if (ny) {
+    if (!isNull(y)) {
 	SEXP t;
 	SET_VECTOR_ELT(r, 1, (t = allocVector(INTSXP, ny)));
 	
@@ -407,7 +408,6 @@ SEXP _match_matrix(SEXP x, SEXP y, SEXP _nm) {
     }
 
     // Unique.
-    UNPROTECT_PTR(ht);
 
     SEXP t;
     SET_VECTOR_ELT(r, 1, (t = allocVector(INTSXP, n)));
@@ -419,7 +419,16 @@ SEXP _match_matrix(SEXP x, SEXP y, SEXP _nm) {
 	    n++;
 	}
 
-    UNPROTECT(1);
+    UNPROTECT(2);
     return r;
 }
 
+
+// Use with care!
+SEXP _stripDimNamesNames(SEXP x) {
+    SEXP d = getAttrib(x, R_DimNamesSymbol);
+    if (!isNull(d))
+	setAttrib(d, R_NamesSymbol, R_NilValue);
+    return x;
+}
+
